/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.bpm.console.client;

import com.gwtext.client.widgets.Panel;

import java.util.List;
import java.util.ArrayList;

/**
 * An editor can be plugged into a {@link org.jboss.bpm.console.client.Workspace}
 *
 * @author Heiko.Braun <heiko.braun@jboss.com>
 */
public abstract class Editor extends Panel
{
  protected ApplicationContext appContext;
  protected List<String> managedTabs;

  public Editor(ApplicationContext applicationContext)
  {
    super();
    this.appContext = applicationContext;
    this.managedTabs = new ArrayList<String>();
    this.setPaddings(10);
  }

  public abstract String getEditorId();

  public abstract String getTitle();

  public abstract String getIconCSS();

  public abstract MenuSection provideMenuSection();

  public boolean hasView(String viewId)
  {
    final String tabId = viewId + ".tab";
    return appContext.getWorkpace().hasItem(tabId);    
  }

  public void showView(String viewId)
  {
    final String tabId = viewId + ".tab";
    appContext.getWorkpace().setActiveTab(tabId);
  }

  public void addView(View view, boolean closable)
  {
    String tabId = view.getViewId() + ".tab";

    view.setId(tabId); // tabId != viewId
    view.setClosable(closable);
    view.setIconCls(view.getIconCSS());
    view.setAutoScroll(true);

    appContext.getWorkpace().add(view);
    appContext.getWorkpace().setActiveTab(view.getId());

    managedTabs.add(tabId);

  }

  public void closeViews()
  {
    for(String tabId : managedTabs)
    {
      Panel tab = appContext.getWorkpace().getItem(tabId);
      if(tab!=null)
      {
        tab.collapse();
      }
    }
  }

  class WrapperPanel extends Panel
  {
    public WrapperPanel(String id)
    {
      super();
      setId(id);
    }
  }
}
