/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2006, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.bpm.console.client.util;

import com.gwtext.client.widgets.grid.Renderer;
import com.gwtext.client.widgets.grid.CellMetadata;
import com.gwtext.client.data.Store;
import com.gwtext.client.data.Record;

import java.util.Date;

import org.jboss.bpm.console.client.model.util.SimpleDateFormat;

/**
 * Renders a Date according to {@link org.jboss.bpm.console.client.model.util.SimpleDateFormat#DEFAULT_FORMAT}
 *
 * @author Heiko.Braun <heiko.braun@jboss.com>
 */
public class DateRenderer implements Renderer
{
  private String fieldName;

  public DateRenderer(String fieldName)
  {
    this.fieldName = fieldName;
  }

  /**
   * Returns an empty string (field is null) or a formatted date (field is set).
   */
  public String render(Object value, CellMetadata cellMetadata, Record record,
                       int rowIndex, int colNum, Store store)
  {
    String s = "";
    SimpleDateFormat df = new SimpleDateFormat();
    Date d = record.getAsDate(fieldName);
    if (d != null)
      s = df.format(d);

    return s;
  }
}